summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ssl/ssl_policy.cc
diff options
context:
space:
mode:
authorpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-05-18 18:28:48 +0000
committerpkasting@chromium.org <pkasting@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-05-18 18:28:48 +0000
commitb4e75c12dacc0922694b12b687a48dd2d973b595 (patch)
tree23d65e13ccf2fd9535ffb7ad965c5f2826efd6cc /chrome/browser/ssl/ssl_policy.cc
parent15ad5dcb44ab2049103f738625e4e5f2483d85da (diff)
downloadchromium_src-b4e75c12dacc0922694b12b687a48dd2d973b595.zip
chromium_src-b4e75c12dacc0922694b12b687a48dd2d973b595.tar.gz
chromium_src-b4e75c12dacc0922694b12b687a48dd2d973b595.tar.bz2
Rename "mixed content" to "insecure content" in as many places as possible, to standardize on a consistent naming scheme.
BUG=none TEST=none Review URL: http://codereview.chromium.org/2069005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@47531 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ssl/ssl_policy.cc')
-rw-r--r--chrome/browser/ssl/ssl_policy.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/browser/ssl/ssl_policy.cc b/chrome/browser/ssl/ssl_policy.cc
index 4405972..768422f 100644
--- a/chrome/browser/ssl/ssl_policy.cc
+++ b/chrome/browser/ssl/ssl_policy.cc
@@ -125,13 +125,13 @@ void SSLPolicy::OnRequestStarted(SSLRequestInfo* info) {
if (info->resource_type() != ResourceType::MAIN_FRAME &&
info->resource_type() != ResourceType::SUB_FRAME) {
// The frame's origin now contains mixed content and therefore is broken.
OriginRanInsecureContent(info->frame_origin(), info->child_id());
}
if (info->resource_type() != ResourceType::MAIN_FRAME) {
// The main frame now contains a frame with mixed content. Therefore, we
// mark the main frame's origin as broken too.
OriginRanInsecureContent(info->main_frame_origin(), info->child_id());
}
}
@@ -165,17 +165,17 @@ void SSLPolicy::UpdateEntry(NavigationEntry* entry, TabContents* tab_contents) {
SiteInstance* site_instance = entry->site_instance();
// Note that |site_instance| can be NULL here because NavigationEntries don't
// necessarily have site instances. Without a process, the entry can't
- // possibly have mixed content. See bug http://crbug.com/12423.
+ // possibly have insecure content. See bug http://crbug.com/12423.
if (site_instance &&
backend_->DidHostRunInsecureContent(entry->url().host(),
site_instance->GetProcess()->id())) {
entry->ssl().set_security_style(SECURITY_STYLE_AUTHENTICATION_BROKEN);
- entry->ssl().set_ran_mixed_content();
+ entry->ssl().set_ran_insecure_content();
return;
}
if (tab_contents->displayed_insecure_content())
- entry->ssl().set_displayed_mixed_content();
+ entry->ssl().set_displayed_insecure_content();
}
////////////////////////////////////////////////////////////////////////////////
@@ -125,13 +125,13 @@ void SSLPolicy::OnRequestStarted(SSLRequestInfo* info) {
if (info->resource_type() != ResourceType::MAIN_FRAME &&
info->resource_type() != ResourceType::SUB_FRAME) {
- // The frame's origin now contains mixed content and therefore is broken.
+ // The frame's origin now contains insecure content.
OriginRanInsecureContent(info->frame_origin(), info->child_id());
}
@@ -125,13 +125,13 @@ void SSLPolicy::OnRequestStarted(SSLRequestInfo* info) {
}
if (info->resource_type() != ResourceType::MAIN_FRAME) {
- // The main frame now contains a frame with mixed content. Therefore, we
- // mark the main frame's origin as broken too.
+ // The main frame now contains a frame with insecure content. Therefore,
+ // we mark the main frame's origin as broken too.
OriginRanInsecureContent(info->main_frame_origin(), info->child_id());
}